# Object Detection Analysis

SmooSense helps evaluate object detection models by visually comparing their predicted bounding boxes against the ground truth. This provides an intuitive way to audit the model's accuracy and identify specific errors on a given dataset.

This example shows COCO dataset object detection results comparing ground truth bounding boxes with model predictions.

## Data Source

Data is excerpted from: COCO2017 Object Detection Dataset